macro_rules! impl_inquire_selection {
($enum_name:ident, $carry_on_name:tt) => { ... };
}Expand description
Macro to implement Inquire for enums that derive EnumIter
macro_rules! impl_inquire_selection {
($enum_name:ident, $carry_on_name:tt) => { ... };
}Macro to implement Inquire for enums that derive EnumIter